/*
 * Copyright 2013 Dashing Rocket, Ltd.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 *     
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 */

package com.dashingrocket.common;

import org.apache.maven.artifact.versioning.ComparableVersion;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * @author jbowes
 *
 */
public final class Version {
	
	private static Logger logger = LoggerFactory.getLogger(Version.class);
	
	private Version() {}
	
	/**
	 * Compare 2 Maven version strings
	 * @param version1 The first version
	 * @param version2 The second version
	 * @return true if version2 is greater than version1, false otherwise.
	 */
	public static boolean compareVersions(final String version1, final String version2) {
		logger.debug("Comparing {} to {}.", version1, version2);
		ComparableVersion v1 = new ComparableVersion(version1);
		v1.parseVersion(version1);
		ComparableVersion v2 = new ComparableVersion(version1);
		v2.parseVersion(version2);
		return (v1.compareTo(v2) < 0);
	}
}
