/*
 * Copyright 2013 Dashing Rocket, Ltd.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 *     
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 */

package com.dashingrocket.common;

import java.awt.Desktop;
import java.io.IOException;
import java.net.URI;
import java.net.URISyntaxException;

import org.apache.http.HttpResponse;
import org.apache.http.HttpStatus;
import org.apache.http.client.HttpClient;
import org.apache.http.client.HttpResponseException;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.http.util.EntityUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * @author jbowes
 * 
 */
public final class Web {

	private static Logger logger = LoggerFactory.getLogger(Web.class);
	
	private Web() {}

	/**
	 * Gets the contents of a webpage at a URL
	 * @param url The URL to parse
	 * @return String of contents
	 * @throws IOException
	 */
	public static String getWebpageContents(final String url) throws IOException {
		logger.debug("Get Webpage Contents");
		HttpClient httpclient = new DefaultHttpClient();
		HttpGet request = new HttpGet(url);
		HttpResponse response = httpclient.execute(request);

		if (response.getStatusLine().getStatusCode() != HttpStatus.SC_OK) {
			httpclient.getConnectionManager().shutdown();
			throw new HttpResponseException(response.getStatusLine().getStatusCode(), response.getStatusLine()
					.getReasonPhrase());
		}
		String content = EntityUtils.toString(response.getEntity()); 
		httpclient.getConnectionManager().shutdown();

		return content;
	}

	/**
	 * Opens a url in the default browser.  If no http/https provided at beginning, it's appended.
	 * @param url The url to open
	 * @throws URISyntaxException
	 * @throws IOException
	 */
	public static void openLink(final String url) throws URISyntaxException, IOException {
		logger.debug("Opening Link: {}", url);
		String destUrl;
		if (!url.startsWith("http://") && !url.startsWith("https://")) {
			logger.info("Did not find http or https protocol.  Adding it");
			destUrl = "http://" + url;
		} else {
			destUrl = url;
		}
		open(new URI(destUrl));
	}
	
	/**
	 * Opens a URI to a specific location
	 * @param uri
	 * @throws IOException
	 */
	public static void open(URI uri) throws IOException {
		Desktop.getDesktop().browse(uri);
	}
}
